pub struct ContractDocument {
pub version: u32,
pub uses: Vec<ContractUse>,
}Expand description
Versioned serialized contract document for stable inspection and tooling.
Fields
version: u32Serialized contract format version.
uses: Vec<ContractUse>Canonical contract uses carried by the document.
Implementations
Sourceimpl ContractDocument
impl ContractDocument
Sourcepub fn from_contract_uses(uses: Vec<ContractUse>) -> ContractDocument
pub fn from_contract_uses(uses: Vec<ContractUse>) -> ContractDocument
Canonicalizes contract uses and wraps them in the current format.