pub fn load_policy_inputs(
paths: &[PathBuf],
options: &PolicyInputOptions,
) -> EngineResult<PolicyInputs>Expand description
Loads and prepares override schemas according to reference and fetch policy.
Errors
Returns an error when an override exceeds its load budget, cannot be read or decoded, or contains references that policy cannot prepare.