load_policy_inputs

Function load_policy_inputs 

pub fn load_policy_inputs(
    paths: &[PathBuf],
    options: &PolicyInputOptions,
) -> EngineResult<PolicyInputs>
Loads and prepares override schemas according to reference and fetch policy.

Errors

Returns an error when an override exceeds its load budget, cannot be read or decoded, or contains references that policy cannot prepare.